@@ -1,6 +1,6 @@
 """Steadfast Courier Python SDK."""
 
-from .client import SteadastClient
+from .client import SteadfastClient
 from .exceptions import (
     SteadfastException,
     AuthenticationError,
@@ -25,10 +25,10 @@ from .models import (
     PoliceStationList,
 )
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 __all__ = [
-    "SteadastClient",
+    "SteadfastClient",
     "SteadfastException",
     "AuthenticationError",
     "ValidationError",
